@@ -8,8 +8,6 @@ PONG = SimpleString(b"PONG")
 
 
 class ConnectionCommandsMixin:
-    # Connection commands
-    # TODO: auth, quit
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super(ConnectionCommandsMixin, self).__init__(*args, **kwargs)
@@ -32,7 +30,7 @@ class ConnectionCommandsMixin:
         else:
             return args[0] if args else PONG
 
-    @command((DbIndex,))
+    @command(name="SELECT", fixed=(DbIndex,))
     def select(self, index: DbIndex) -> SimpleString:
         self._db = self._server.dbs[index]
         self._db_num = index  # type: ignore
